summaryrefslogtreecommitdiffstats
path: root/src/svnqt/client_impl.hpp
diff options
context:
space:
mode:
Diffstat (limited to 'src/svnqt/client_impl.hpp')
-rw-r--r--src/svnqt/client_impl.hpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/svnqt/client_impl.hpp b/src/svnqt/client_impl.hpp
index 9afc062..bd6a599 100644
--- a/src/svnqt/client_impl.hpp
+++ b/src/svnqt/client_impl.hpp
@@ -189,11 +189,11 @@ namespace svn
* @param depth if @a path is a folder add items recursive depending on value if it. Pre-subversion 1.5 DepthInfinity is mapped to recursive, all other to not-recursive.
* @param force if true, do not error on already-versioned items.
* @param no_ignore if false don't add files or directories that match ignore patterns.
* @param add_tqparents if true, go up to the next versioned folder and add all between path and this folder. Used only with subversion 1.5 or newer
* @exception ClientException
* @sa svn::Depth
*/
- virtual void add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_tqparents = true) throw (ClientException);
+ virtual void add (const Path & path, svn::Depth depth,bool force=false, bool no_ignore=false, bool add_parents = true) throw (ClientException);
/**
* Updates the file or directory.
@@ -189,11 +189,11 @@ namespace svn
* @param force if true, do not error on already-versioned items.
* @param no_ignore if false don't add files or directories that match ignore patterns.
- * @param add_tqparents if true, go up to the next versioned folder and add all between path and this folder. Used only with subversion 1.5 or newer
+ * @param add_parents if true, go up to the next versioned folder and add all between path and this folder. Used only with subversion 1.5 or newer
* @exception ClientException
* @sa svn::Depth